==> libgda-3.99.10.tar.bz2: libgda-3.99.10/libgda/sqlite/gda-sqlite-blob-op.h <==
/* GDA Sqlite provider
 * Copyright (C) 2009 The GNOME Foundation
 *
 * AUTHORS:
 *      Vivien Malerba <malerba@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GDA_SQLITE_BLOB_OP_H__
#define __GDA_SQLITE_BLOB_OP_H__

#include <libgda/gda-blob-op.h>

G_BEGIN_DECLS

#define GDA_TYPE_SQLITE_BLOB_OP            (gda_sqlite_blob_op_get_type())
#define GDA_SQLITE_BLOB_OP(obj)            (G_TYPE_CHECK_INSTANCE_CAST (obj, GDA_TYPE_SQLITE_BLOB_OP, GdaSqliteBlobOp))
#define GDA_SQLITE_BLOB_OP_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GDA_TYPE_SQLITE_BLOB_OP, GdaSqliteBlobOpClass))
#define GDA_IS_SQLITE_BLOB_OP(obj)         (G_TYPE_CHECK_INSTANCE_TYPE (obj, GDA_TYPE_SQLITE_BLOB_OP))
#define GDA_IS_SQLITE_BLOB_OP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GDA_TYPE_SQLITE_BLOB_OP))

typedef struct _GdaSqliteBlobOp        GdaSqliteBlobOp;
typedef struct _GdaSqliteBlobOpClass   GdaSqliteBlobOpClass;
typedef struct _GdaSqliteBlobOpPrivate GdaSqliteBlobOpPrivate;

struct _GdaSqliteBlobOp {
	GdaBlobOp             parent;
	GdaSqliteBlobOpPrivate *priv;
};

struct _GdaSqliteBlobOpClass {
	GdaBlobOpClass        parent_class;
};

GType         gda_sqlite_blob_op_get_type     (void) G_GNUC_CONST;
GdaBlobOp    *gda_sqlite_blob_op_new          (SqliteConnectionData *cdata, const gchar *db_name, const gchar *table_name,
					       const gchar *column_name, sqlite3_int64 rowid);

G_END_DECLS

#endif

==> libgda-4.1.1.tar.bz2: libgda-4.1.1/libgda/sqlite/gda-sqlite-blob-op.h <==
/* GDA Sqlite provider
 * Copyright (C) 2009 The GNOME Foundation
 *
 * AUTHORS:
 *      Vivien Malerba <malerba@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GDA_SQLITE_BLOB_OP_H__
#define __GDA_SQLITE_BLOB_OP_H__

#include <libgda/gda-blob-op.h>

G_BEGIN_DECLS

#define GDA_TYPE_SQLITE_BLOB_OP            (_gda_sqlite_blob_op_get_type())
#define GDA_SQLITE_BLOB_OP(obj)            (G_TYPE_CHECK_INSTANCE_CAST (obj, GDA_TYPE_SQLITE_BLOB_OP, GdaSqliteBlobOp))
#define GDA_SQLITE_BLOB_OP_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GDA_TYPE_SQLITE_BLOB_OP, GdaSqliteBlobOpClass))
#define GDA_IS_SQLITE_BLOB_OP(obj)         (G_TYPE_CHECK_INSTANCE_TYPE (obj, GDA_TYPE_SQLITE_BLOB_OP))
#define GDA_IS_SQLITE_BLOB_OP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GDA_TYPE_SQLITE_BLOB_OP))

typedef struct _GdaSqliteBlobOp        GdaSqliteBlobOp;
typedef struct _GdaSqliteBlobOpClass   GdaSqliteBlobOpClass;
typedef struct _GdaSqliteBlobOpPrivate GdaSqliteBlobOpPrivate;

struct _GdaSqliteBlobOp {
	GdaBlobOp             parent;
	GdaSqliteBlobOpPrivate *priv;
};

struct _GdaSqliteBlobOpClass {
	GdaBlobOpClass        parent_class;
};

GType         _gda_sqlite_blob_op_get_type     (void) G_GNUC_CONST;
GdaBlobOp    *_gda_sqlite_blob_op_new          (SqliteConnectionData *cdata, const gchar *db_name, const gchar *table_name,
					       const gchar *column_name, sqlite3_int64 rowid);

G_END_DECLS

#endif
